| Title: | `gaRbage` is an R package for that random but sometimes useful code. |
|---|---|
| Description: | `gaRbage` is an R package for that random but sometimes useful code. |
| Authors: | Eric Hunt |
| Maintainer: | Eric Hunt <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-14 05:53:18 UTC |
| Source: | https://github.com/eric-hunt/gaRbage |
Get the GC content of a nucleic acid sequence
seq_gc(seq, digits = 4)seq_gc(seq, digits = 4)
seq |
A string - the nucleic acid sequence formatted as a single string |
digits |
An integer - rounding precision for the result (see [base::round()]) |
A double, the GC content of *seq*, with precision defined by *digits*
Get the reverse complement of a nucleic acid sequence
seq_revcomp(seq)seq_revcomp(seq)
seq |
A string - the nucleic acid sequence formatted as a single string |
A string - the reverse complement of *seq*